"""
Solicitor: uses metadata.json to determine input parameters for ingestion
"""
import json
import pathlib


class Solicitor:
    def __init__(self, filename: str):
        self.filename = filename
        self.metadata = self.solicit_contents()

    def solicit_contents(self) -> dict:
        with open(self.filename) as file:
            metadata = json.loads(file.read())
            return metadata

    def solicit_workflow_directory_name(self):
        destination_path = pathlib.Path(self.metadata["destinationDirectory"])
        return destination_path.stem

    def solicit_processing_creation_time(self):
        # incoming datetime: 2021-07-06T21:50:48
        # transformation for NGAS friendliness: 2021_07_06T21_50_48
        creation_time = self.metadata["creationTime"].replace("-", "_").replace(":", "_")
        return creation_time

    def solicit_parameters(self):
        metadata = self.solicit_contents()
        return {
            "sdmId": metadata["fileSetIds"],
            "workflowName": metadata["workflowName"],
            "workflowRequestId": metadata["systemId"],
            "spl": metadata["productLocator"],
            "processingStart": self.solicit_processing_creation_time(),
            "destinationDir": metadata["destinationDirectory"],
            "workflowDir": self.solicit_workflow_directory_name(),
        }
