""" Various 'n' sundry utilities for our tests """

# pylint: disable=E0401, R1721

from pathlib import Path
from typing import List

import pytest

from ingest_envoy.manifest_components import WEBLOG

WANTED_FILENAMES = ["my_science_products.tar", WEBLOG]
UNWANTED = ["ignore_me.fits", "just_a_lotta_nothing", "uninteresting_metadata.xml"]


@pytest.fixture(scope="function")
def ingest_path(tmpdir: Path) -> Path:
    """
    Make an "ingestion path" for tests

    :param tmpdir: temporary home for ingestion location
    :return:
    """

    # cast is necessary because otherwise we get a LocalPath, which doesn't work
    fake_ingest_path = Path(tmpdir / "ingestion")
    fake_ingest_path.mkdir()
    return fake_ingest_path


def find_example_manifest(manifest_name: str) -> Path:
    """
    Get this example manifest for comparison with one we've generated in a test.

    :param manifest_name: unique file identifier
    :return: full path to the manifest file
    """
    filename = manifest_name + ".json"
    for file in Path.cwd().rglob(filename):
        return file

    raise FileNotFoundError(filename)


def populate_fake_evla_cal_ingest_path(staging_dir: Path) -> List[Path]:
    """
    Create a directory containing fake calibration products, plus other stuff
    that we -don't- want to ingest.

    :param staging_dir: our temporary dir
    :return:
    """

    files = []
    filenames = [filename for filename in WANTED_FILENAMES]
    for filename in UNWANTED:
        filenames.append(filename)

    for filename in filenames:
        path = staging_dir / filename
        path.touch()
        files.append(path)

    return files
